@@ -1,5 +1,7 @@
-import pydantic
+import typing
 
+import pydantic
+import exch
 
 class oDataUrl(pydantic.AnyHttpUrl):
     user_required: bool = True
@@ -23,3 +25,15 @@ class InformationRegister(pydantic.BaseModel):
         base_url += "/odata/standard.odata/InformationRegister_{InformationRegister}?$format=json" \
             .format(InformationRegister=cls.__name__)
         return cls._get_url(base_url=pydantic.StrictStr(base_url))
+
+
+class PacketsOfTabDataSourcesMixin(pydantic.BaseModel):
+    Hash: pydantic.StrictStr = pydantic.Field(exclusiveRegex="^[0-9a-FA-F]{40}$")
+    Format: pydantic.StrictStr = pydantic.Field(exclusiveRegex="^[0-9a-FA-F]{40}$")
+    Packet: exch.FormatPacket
+
+
+class PacketsOfTabDataMixin(pydantic.BaseModel):
+    FileName: pydantic.StrictStr
+    Source: pydantic.StrictStr = pydantic.Field(exclusiveRegex="^[0-9a-FA-F]{40}$")
+    Packet: exch.Packet
